==> prettyqt-1.48.0-py3-none-any.whl: prettyqt/widgets/boxlayout.py <==
from __future__ import annotations

from typing import Literal

from prettyqt import widgets
from prettyqt.qt import QtWidgets
from prettyqt.utils import InvalidParamError, bidict


DIRECTION = bidict(
    left_to_right=QtWidgets.QBoxLayout.Direction.LeftToRight,
    right_to_left=QtWidgets.QBoxLayout.Direction.RightToLeft,
    top_to_bottom=QtWidgets.QBoxLayout.Direction.TopToBottom,
    bottom_to_top=QtWidgets.QBoxLayout.Direction.BottomToTop,
)

DirectionStr = Literal["left_to_right", "right_to_left", "top_to_bottom", "bottom_to_top"]


class BoxLayoutMixin(widgets.LayoutMixin):
    # def __init__(
    #     self,
    #     orientation: Literal["horizontal", "vertical"] = "horizontal",
    #     parent: QtWidgets.QWidget | None = None,
    #     margin: int | None = None,
    # ):

    #     if margin is not None:
    #         self.set_margin(margin)

    # def __setstate__(self, state):
    #     super().__setstate__(state)
    #     self.set_direction(state["direction"])
    #     for item in state["items"]:
    #         self.add(item)

    # def __reduce__(self):
    #     return type(self), (), self.__getstate__()

    # def __add__(self, other: QtWidgets.QWidget | QtWidgets.QLayout):
    #     self.add(other)
    #     return self

    # def add(self, *item):
    #     for i in item:
    #         if isinstance(i, QtWidgets.QWidget):
    #             self.addWidget(i)
    #         else:
    #             self.addLayout(i)

    def add_stretch(self, stretch: int = 0):
        self.addStretch(stretch)

    def add_spacing(self, size: int):
        self.addSpacing(size)

    def set_direction(self, direction: DirectionStr):
        """Set the direction.

        Args:
            direction: direction

        Raises:
            InvalidParamError: direction does not exist
        """
        if direction not in DIRECTION:
            raise InvalidParamError(direction, DIRECTION)
        self.setDirection(DIRECTION[direction])

    def get_direction(self) -> DirectionStr:
        """Return current direction.

        Returns:
            direction
        """
        return DIRECTION.inverse[self.direction()]


class BoxLayout(BoxLayoutMixin, QtWidgets.QBoxLayout):
    ID = "box"
    pass


if __name__ == "__main__":
    app = widgets.app()
    layout = BoxLayout("vertical")
    widget = widgets.Widget()
    widget2 = widgets.RadioButton("Test")
    layout.add(widget2)
    widget.set_layout(layout)
    widget.show()
    app.main_loop()

==> prettyqt-1.49.0-py3-none-any.whl: prettyqt/widgets/boxlayout.py <==
from __future__ import annotations

from typing import Literal

from prettyqt import widgets
from prettyqt.qt import QtWidgets
from prettyqt.utils import bidict


DIRECTION = bidict(
    left_to_right=QtWidgets.QBoxLayout.Direction.LeftToRight,
    right_to_left=QtWidgets.QBoxLayout.Direction.RightToLeft,
    top_to_bottom=QtWidgets.QBoxLayout.Direction.TopToBottom,
    bottom_to_top=QtWidgets.QBoxLayout.Direction.BottomToTop,
)

DirectionStr = Literal["left_to_right", "right_to_left", "top_to_bottom", "bottom_to_top"]


class BoxLayoutMixin(widgets.LayoutMixin):
    # def __init__(
    #     self,
    #     orientation: Literal["horizontal", "vertical"] = "horizontal",
    #     parent: QtWidgets.QWidget | None = None,
    #     margin: int | None = None,
    # ):

    #     if margin is not None:
    #         self.set_margin(margin)

    # def __setstate__(self, state):
    #     super().__setstate__(state)
    #     self.set_direction(state["direction"])
    #     for item in state["items"]:
    #         self.add(item)

    # def __reduce__(self):
    #     return type(self), (), self.__getstate__()

    # def __add__(self, other: QtWidgets.QWidget | QtWidgets.QLayout):
    #     self.add(other)
    #     return self

    # def add(self, *item):
    #     for i in item:
    #         if isinstance(i, QtWidgets.QWidget):
    #             self.addWidget(i)
    #         else:
    #             self.addLayout(i)

    def add_stretch(self, stretch: int = 0):
        self.addStretch(stretch)

    def add_spacing(self, size: int):
        self.addSpacing(size)

    def set_direction(self, direction: DirectionStr | BoxLayout.Direction):
        """Set the direction.

        Args:
            direction: direction
        """
        if isinstance(direction, str):
            direction = DIRECTION[direction]
        self.setDirection(direction)

    def get_direction(self) -> DirectionStr:
        """Return current direction.

        Returns:
            direction
        """
        return DIRECTION.inverse[self.direction()]


class BoxLayout(BoxLayoutMixin, QtWidgets.QBoxLayout):
    ID = "box"
    pass


if __name__ == "__main__":
    app = widgets.app()
    layout = BoxLayout("vertical")
    widget = widgets.Widget()
    widget2 = widgets.RadioButton("Test")
    layout.add(widget2)
    widget.set_layout(layout)
    widget.show()
    app.main_loop()
